.. _module_ext_client_core_tooltip:

tooltip
=======

This sections contains module documentation of tooltip module.

ToolTip
^^^^^^^

Class for ToolTip widget.

**Attributes** :

* _parent - Button instance reference
* _text - tooltip text
* _win - popup window

**Methods** :

* __init__

Constructor, set parent events.

* _display

Method displays tooltip window.